Welcome to PySwarms's documentation!
======================================

.. image:: https://badge.fury.io/py/pyswarms.svg
        :target: https://badge.fury.io/py/pyswarms

.. image:: https://img.shields.io/travis/ljvmiranda921/pyswarms.svg
        :target: https://travis-ci.org/ljvmiranda921/pyswarms

.. image:: https://readthedocs.org/projects/pyswarms/badge/?version=latest
        :target: https://pyswarms.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://landscape.io/github/ljvmiranda921/pyswarms/master/landscape.svg?style=flat
   :target: https://landscape.io/github/ljvmiranda921/pyswarms/master
   :alt: Code Health

.. image:: https://pyup.io/repos/github/ljvmiranda921/pyswarms/shield.svg
     :target: https://pyup.io/repos/github/ljvmiranda921/pyswarms/
     :alt: Updates

.. image:: https://img.shields.io/badge/license-MIT-blue.svg   
     :target: https://raw.githubusercontent.com/ljvmiranda921/pyswarms/master/LICENSE

PySwarms is a simple, Python-based, Particle Swarm Optimization (PSO) library.

* Free software: MIT license
* Github repository: https://github.com/ljvmiranda921/pyswarms

Launching pad
-------------

* If you don't know what Particle Swarm Optimization is, read up this short `Introduction <http://pyswarms.readthedocs.io/en/latest/intro.html>`_! Then, if you plan to use PySwarms in your project, check the `Installation guide <https://pyswarms.readthedocs.io/en/latest/installation.html>`_ and the `use-case examples <https://pyswarms.readthedocs.io/en/latest/examples/usecases.html>`_ in this documentation.

* If you are a researcher in the field of swarm intelligence, and would like to include your technique in our list of optimizers, check our `contributing <https://pyswarms.readthedocs.io/en/latest/contributing.html>`_ page to see how to implement your optimizer using the current base classes in the library.

* If you are an open-source contributor, and would like to help PySwarms grow, be sure to check our `Issues <https://github.com/ljvmiranda921/pyswarms/issues>`_ page in Github, and see the open issues with the tag `help-wanted <https://github.com/ljvmiranda921/pyswarms/labels/help%20wanted>`_. Moreover, we accommodate contributions from first-time contributors! Just check our `first-timers-only <https://github.com/ljvmiranda921/pyswarms/labels/first-timers-only>`_ tag for open issues (Don't worry! We're happy to help you make your first PR!).


.. toctree::
   :maxdepth: 2
   :caption: General

   intro
   features
   installation
   authors
   history

.. toctree::
   :maxdepth: 2
   :caption: Examples

   Use-cases <examples/usecases>

.. toctree::
   :maxdepth: 2
   :caption: Developer's Guide

   contributing
   API Documentation <api/pyswarms>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
